@@ -1,6 +1,6 @@
 package MooseX::UndefTolerant::Attribute;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -44,7 +44,7 @@ MooseX::UndefTolerant::Attribute - Make your attribute(s) tolerant to undef init
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -68,16 +68,27 @@ version 0.20
 
 =head1 DESCRIPTION
 
-Applying this trait to your attribute makes it's initialization tolerant of
+Applying this trait to your attribute makes its initialization tolerant of
 of undef.  If you specify the value of undef to any of the attributes they
 will not be initialized (or will be set to the default, if applicable).
 Effectively behaving as if you had not provided a value at all.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-UndefTolerant>
+(or L<bug-MooseX-UndefTolerant@rt.cpan.org|mailto:bug-MooseX-UndefTolerant@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Cory G Watson <gphat at cpan.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Cory G Watson.
 
